import { Converter } from "./converter/converter";
import type { ProjectReflection } from "./models/index";
import { Serializer } from "./serialization";
import { Logger, Options, TypeDocAndTSOptions } from "./utils";
import { Renderer } from "./renderer";
export declare class Application {
    /**
     * The converter used to create the declaration reflections.
     */
    readonly converter: Converter;
    /**
     * The serializer used to generate JSON output.
     */
    readonly serializer: Serializer;
    /**
     * Component used to render reflections into output that is human readable.
     */
    readonly renderer: Renderer;
    /**
     * The logger that should be used to output messages.
     */
    logger: Logger;
    /**
     * Container describing all TypeDoc + TS options.
     */
    readonly options: Options;
    /**
     * Create a new TypeDoc application instance.
     *
     * @param options An object containing the options that should be used.
     */
    constructor();
    /**
     * Initialize TypeDoc with the given options object.
     *
     * @param options  The desired options to set.
     */
    bootstrap(options?: Partial<TypeDocAndTSOptions>): void;
    /**
     * Run the converter for the given set of files and return the generated reflections.
     *
     * @param src  A list of source that should be compiled and converted.
     * @returns An instance of ProjectReflection on success, undefined otherwise.
     */
    convert(): Promise<ProjectReflection | undefined>;
    /**
     * Emit rendered documentation for the given project.
     * @param out the directory to write the rendered documentation to.
     */
    generateDocs(project: ProjectReflection, out: string): Promise<void>;
    /**
     * Run the converter for the given set of files and write the reflections to a json file.
     *
     * @param out The path and file name to write the serialized project to.
     */
    generateJson(project: ProjectReflection, out: string): Promise<void>;
}
