"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Context = void 0;
const array_1 = require("../utils/array");
class Context {
    constructor(program, converter, project, container) {
        this.program = program;
        this.converter = converter;
        this.project = project;
        this.container = container;
    }
    get checker() {
        return this.program.getTypeChecker();
    }
    getExportsOfKind(symbol, kind) {
        var _a;
        const kinds = Array.isArray(kind) ? kind : [kind];
        const result = [];
        (_a = symbol.exports) === null || _a === void 0 ? void 0 : _a.forEach((child) => {
            var _a;
            if ((_a = child.getDeclarations()) === null || _a === void 0 ? void 0 : _a.some((decl) => kinds.includes(decl.kind))) {
                result.push(child);
            }
        });
        return result;
    }
    getExportsWithFlag(symbol, flag) {
        var _a;
        const result = [];
        (_a = symbol.exports) === null || _a === void 0 ? void 0 : _a.forEach((child) => {
            if (child.flags & flag) {
                result.push(child);
            }
        });
        return result;
    }
    getExports(symbol) {
        var _a;
        const result = [];
        (_a = symbol.exports) === null || _a === void 0 ? void 0 : _a.forEach((child) => {
            result.push(child);
        });
        return result;
    }
    async convertChildren(children, parent) {
        // Note: This doesn't use Promise.all intentionally, doing so results in nondeterministic builds.
        await array_1.waterfall(children, (child) => this.converter.convertSymbol(child, this.withContainer(parent)));
    }
    withContainer(container) {
        return new Context(this.program, this.converter, this.project, container);
    }
}
exports.Context = Context;
//# sourceMappingURL=context.js.map