import * as ts from "typescript";
import type { Application } from "../application";
import { ModuleReflection, ProjectReflection, SomeContainerReflection, SomeReflection, SomeType } from "../models/index";
import { ObjectReflection } from "../models/reflections/object";
import type { Options, Logger } from "../utils";
import { EventEmitter } from "../utils/event";
import { Context } from "./context";
import { ReflectionConverter } from "./nodes";
import { TypeConverter } from "./types";
interface ConverterEventMap {
    begin: [ProjectReflection, ts.Program];
    reflectionCreated: [SomeReflection, ts.Symbol, ts.Node[]];
    moduleCreated: [ModuleReflection | ProjectReflection, ts.SourceFile];
    end: [ProjectReflection];
}
export declare class Converter extends EventEmitter<ConverterEventMap> {
    readonly application: Application;
    /** @event */
    static readonly EVENT_BEGIN = "begin";
    /** @event */
    static readonly EVENT_END = "end";
    /**
     * Fired for all reflection creation events except the creation of the main
     * project reflection and the module reflections contained within it.
     *
     * This cannot be fired for module reflections since, if a file is global,
     * there will not be a TypeScript symbol associated with it. Similarly, the
     * project reflection also has no single symbol associated with it. To listen
     * to the creation of a project reflection and module reflection, listen to
     * the {@link BEGIN} and {@link MODULE_CREATED} events, respectively.
     *
     * @event
     */
    static readonly EVENT_REFLECTION_CREATED = "reflectionCreated";
    /** @event */
    static readonly EVENT_MODULE_CREATED = "moduleCreated";
    get options(): Options;
    get logger(): Logger;
    get checker(): ts.TypeChecker;
    get project(): ProjectReflection;
    private _checker?;
    private _project?;
    private _reflectionConverters;
    private _typeNodeConverters;
    private _seenTypeSymbols;
    constructor(application: Application);
    addReflectionConverter(converter: ReflectionConverter): void;
    addTypeNodeConverter(converter: TypeConverter): void;
    convert(program: ts.Program, entryPoints: string[]): Promise<ProjectReflection>;
    convertSymbol<U extends SomeContainerReflection>(symbol: ts.Symbol, context: Context<U>): Promise<void>;
    convertTypeOrObject(typeOrNode: ts.TypeNode | ts.Type | undefined): Promise<SomeType | ObjectReflection>;
    convertType: (typeOrNode: ts.TypeNode | ts.Type | undefined) => SomeType;
    /**
     * Wrapper around checker.getSymbolAtLocation which resolves to the declaration
     * symbol instead of any imported alias symbols.
     * @param node
     */
    getSymbolAtLocation(node: ts.Node): ts.Symbol | undefined;
    private getModuleSymbol;
    private getExportsOfModule;
}
export {};
