"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.classConverter = void 0;
const assert = require("assert");
const ts = require("typescript");
const models_1 = require("../../models");
const signature_1 = require("./signature");
const utils_1 = require("../utils");
const array_1 = require("../../utils/array");
// Note: While this converter is structurally very similar to the interface converter, it is
// different in one important way - classes can have static members.
exports.classConverter = {
    kind: [ts.SyntaxKind.ClassDeclaration],
    async convert(context, symbol, [node]) {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k;
        const signatureSymbol = (_a = symbol.members) === null || _a === void 0 ? void 0 : _a.get("__call");
        const signatures = await array_1.waterfall((_c = (_b = signatureSymbol === null || signatureSymbol === void 0 ? void 0 : signatureSymbol.getDeclarations()) === null || _b === void 0 ? void 0 : _b.filter(ts.isCallSignatureDeclaration)) !== null && _c !== void 0 ? _c : [], (node) => signature_1.convertSignatureDeclaration(context.converter, "__call", node, signatureSymbol));
        const constructSymbol = (_d = symbol.members) === null || _d === void 0 ? void 0 : _d.get("__new");
        const constructSignatures = await array_1.waterfall((_f = (_e = constructSymbol === null || constructSymbol === void 0 ? void 0 : constructSymbol.getDeclarations()) === null || _e === void 0 ? void 0 : _e.filter(ts.isCallSignatureDeclaration)) !== null && _f !== void 0 ? _f : [], (node) => signature_1.convertSignatureDeclaration(context.converter, "__new", node, constructSymbol));
        const implementsClause = (_g = node.heritageClauses) === null || _g === void 0 ? void 0 : _g.find((clause) => clause.token === ts.SyntaxKind.ImplementsKeyword);
        const implementedTypes = (_h = implementsClause === null || implementsClause === void 0 ? void 0 : implementsClause.types.map((type) => {
            const parent = context.converter.convertType(type);
            assert(parent instanceof models_1.ReferenceType);
            return parent;
        })) !== null && _h !== void 0 ? _h : [];
        const extendsClause = (_j = node.heritageClauses) === null || _j === void 0 ? void 0 : _j.find((clause) => clause.token === ts.SyntaxKind.ExtendsKeyword);
        const extendedType = extendsClause
            ? context.converter.convertType(extendsClause.types[0])
            : undefined;
        const typeParameterSymbols = [];
        const members = [];
        (_k = symbol.members) === null || _k === void 0 ? void 0 : _k.forEach((member) => {
            if (member.flags & ts.TypeFlags.TypeParameter) {
                typeParameterSymbols.push(member);
                // We already took care of signatures and construct signatures.
            }
            else if (member.flags & ts.SymbolFlags.FunctionExcludes) {
                members.push(member);
            }
        });
        const typeParameters = utils_1.convertTypeParameterDeclarations(context.converter, typeParameterSymbols.map((symbol) => {
            var _a;
            const param = (_a = symbol.getDeclarations()) === null || _a === void 0 ? void 0 : _a[0];
            assert(param && ts.isTypeParameterDeclaration(param));
            return param;
        }));
        const reflection = new models_1.ClassReflection(symbol.name, signatures, constructSignatures, typeParameters, implementedTypes, extendedType);
        context.project.registerReflection(reflection, symbol);
        await context.convertChildren(members, reflection);
        return reflection;
    },
};
//# sourceMappingURL=class.js.map