"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.enumMemberConverter = exports.enumConverter = void 0;
const assert = require("assert");
const ts = require("typescript");
const models_1 = require("../../models");
exports.enumConverter = {
    kind: [ts.SyntaxKind.EnumDeclaration],
    async convert(context, symbol) {
        const isConst = Boolean(symbol.flags & ts.SymbolFlags.ConstEnum);
        const container = new models_1.EnumReflection(symbol.name, isConst);
        context.project.registerReflection(container, symbol);
        await context.convertChildren(context.getExportsOfKind(symbol, ts.SyntaxKind.EnumMember), container);
        return container;
    },
};
exports.enumMemberConverter = {
    kind: [ts.SyntaxKind.EnumMember],
    convert(context, symbol, [node]) {
        const value = context.checker.getConstantValue(node);
        assert(value !== undefined, "Failed to get the value of an enum. This is probably a bug.");
        const member = new models_1.EnumMemberReflection(symbol.name, value);
        context.project.registerReflection(member, symbol);
        return member;
    },
};
//# sourceMappingURL=enum.js.map