"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.methodConverter = void 0;
const ts = require("typescript");
const models_1 = require("../../models");
const signature_1 = require("./signature");
const utils_1 = require("../utils");
const array_1 = require("../../utils/array");
exports.methodConverter = {
    kind: [ts.SyntaxKind.MethodSignature, ts.SyntaxKind.MethodDeclaration],
    async convert(context, symbol, nodes) {
        // All signatures must have the same visibility.
        const container = new models_1.MethodReflection(symbol.name, utils_1.getVisibility(nodes[0]));
        context.project.registerReflection(container, symbol);
        // With overloads, only the signatures without an implementation are "real"
        const includeImplementation = nodes.length === 1;
        const realNodes = nodes.filter((node) => ts.isMethodDeclaration(node) &&
            Boolean(node.body) === includeImplementation);
        const signatures = await array_1.waterfall(realNodes, (node) => signature_1.convertSignatureDeclaration(context.converter, symbol.name, node, symbol));
        for (const signature of signatures) {
            container.addChild(signature);
        }
        return container;
    },
};
//# sourceMappingURL=method.js.map