"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.parameterPropertyConverter = exports.accessorConverter = exports.propertyConverter = void 0;
const ts = require("typescript");
const models_1 = require("../../models");
const signature_1 = require("./signature");
const utils_1 = require("../utils");
exports.propertyConverter = {
    kind: [ts.SyntaxKind.PropertySignature, ts.SyntaxKind.PropertyDeclaration],
    async convert(context, symbol, [node]) {
        var _a;
        // Convention: In the following, `bar` should be considered a method.
        // class Foo { bar = () => this.something }
        if (node.initializer && ts.isArrowFunction(node.initializer)) {
            const container = new models_1.MethodReflection(symbol.name, utils_1.getVisibility(node));
            context.project.registerReflection(container, symbol);
            container.addChild(await signature_1.convertSignatureDeclaration(context.converter, symbol.name, node.initializer, symbol));
            return container;
        }
        const property = new models_1.PropertyReflection(symbol.name, await context.converter.convertTypeOrObject((_a = node.type) !== null && _a !== void 0 ? _a : context.checker.getTypeOfSymbolAtLocation(symbol, node)), utils_1.getVisibility(node), utils_1.hasReadonlyModifier(node));
        context.project.registerReflection(property, symbol);
        return property;
    },
};
exports.accessorConverter = {
    kind: [ts.SyntaxKind.GetAccessor, ts.SyntaxKind.SetAccessor],
    async convert(context, symbol, [node]) {
        var _a;
        const hasGetter = node.kind === ts.SyntaxKind.GetAccessor;
        const hasSetter = symbol.declarations.some((decl) => decl.kind === ts.SyntaxKind.SetAccessor);
        const property = new models_1.DynamicPropertyReflection(symbol.name, await context.converter.convertTypeOrObject((_a = node.type) !== null && _a !== void 0 ? _a : context.checker.getTypeOfSymbolAtLocation(symbol, node)), utils_1.getVisibility(node), hasGetter, hasSetter);
        context.project.registerReflection(property, symbol);
        return property;
    },
};
// class Foo { constructor(public bar: string) {} }
exports.parameterPropertyConverter = {
    kind: [ts.SyntaxKind.Parameter],
    async convert(context, symbol, [node]) {
        var _a;
        const property = new models_1.PropertyReflection(symbol.name, await context.converter.convertTypeOrObject((_a = node.type) !== null && _a !== void 0 ? _a : context.checker.getTypeOfSymbolAtLocation(symbol, node)), utils_1.getVisibility(node), utils_1.hasReadonlyModifier(node));
        context.project.registerReflection(property, symbol);
        return property;
    },
};
//# sourceMappingURL=property.js.map