"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertSignatureDeclaration = void 0;
const assert = require("assert");
const ts = require("typescript");
const models_1 = require("../../models");
const comments_1 = require("../comments");
const utils_1 = require("../utils");
const array_1 = require("../../utils/array");
async function convertSignatureDeclaration(converter, name, node, symbol) {
    var _a, _b;
    const signature = converter.checker.getSignatureFromDeclaration(node);
    assert(signature, `Failed to get a signature for ${name}. This is likely a bug.`);
    const returnType = await converter.convertTypeOrObject((_a = node.type) !== null && _a !== void 0 ? _a : signature.getReturnType());
    const parameters = await array_1.waterfall(signature.parameters, async (param) => {
        var _a, _b;
        const paramDeclaration = param.valueDeclaration;
        assert(paramDeclaration && ts.isParameter(paramDeclaration)); // Should never fail...
        const paramType = await converter.convertTypeOrObject((_a = paramDeclaration.type) !== null && _a !== void 0 ? _a : converter.checker.getTypeOfSymbolAtLocation(param, paramDeclaration));
        const isOptional = !!paramDeclaration.questionToken || !!paramDeclaration.initializer;
        const parameter = new models_1.ParameterReflection(param.name, "kind" in paramType || !isOptional
            ? paramType
            : utils_1.excludeUndefined(paramType), (_b = paramDeclaration.initializer) === null || _b === void 0 ? void 0 : _b.getText(), isOptional, !!paramDeclaration.dotDotDotToken);
        parameter.comment = comments_1.getCommentForNodes([paramDeclaration]);
        return parameter;
    });
    const typeParameters = utils_1.convertTypeParameters(converter, (_b = signature.getTypeParameters()) !== null && _b !== void 0 ? _b : []);
    const reflection = new models_1.SignatureReflection(name, returnType, parameters, typeParameters);
    converter.project.registerReflection(reflection, symbol);
    reflection.parameters.forEach((param) => (param.parent = reflection));
    // Since we don't go through the converter, we have to set our own comment.
    reflection.comment = comments_1.getCommentForNodes([node]);
    return reflection;
}
exports.convertSignatureDeclaration = convertSignatureDeclaration;
//# sourceMappingURL=signature.js.map