import type { CommentTag } from "./tag";
/**
 * A model that represents a TypeDoc comment.
 *
 * Comments are created by the {@link CommentPlugin} and {@link DeepCommentPlugin}.
 */
export declare class Comment {
    /**
     * The abstract of the comment. TypeDoc interprets the first paragraph of a comment
     * as the abstract.
     */
    shortText: string;
    /**
     * The full body text of the comment. Excludes the {@link shortText}.
     */
    text: string;
    /**
     * All associated tags.
     */
    tags?: CommentTag[];
    /**
     * Creates a new Comment instance.
     */
    constructor(shortText?: string, text?: string);
    /**
     * Test whether this comment contains a tag with the given name.
     *
     * @param tagName  The name of the tag to look for.
     * @returns TRUE when this comment contains a tag with the given name, otherwise FALSE.
     */
    hasTag(tagName: string): boolean;
    /**
     * Return the first tag with the given name.
     *
     * You can optionally pass a parameter name that should be searched to.
     *
     * @param tagName  The name of the tag to look for.
     * @param paramName  An optional parameter name to look for.
     * @returns The found tag or undefined.
     */
    getTag(tagName: string, paramName?: string): CommentTag | undefined;
    /**
     * Removes all tags with the given tag name from this comment.
     */
    removeTags(...tags: string[]): void;
    /**
     * Copy the data of the given comment into this comment.
     *
     * @param comment
     */
    clone(): Comment;
}
