"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Comment = void 0;
/**
 * A model that represents a TypeDoc comment.
 *
 * Comments are created by the {@link CommentPlugin} and {@link DeepCommentPlugin}.
 */
class Comment {
    /**
     * Creates a new Comment instance.
     */
    constructor(shortText = "", text = "") {
        this.shortText = shortText;
        this.text = text;
    }
    /**
     * Test whether this comment contains a tag with the given name.
     *
     * @param tagName  The name of the tag to look for.
     * @returns TRUE when this comment contains a tag with the given name, otherwise FALSE.
     */
    hasTag(tagName) {
        var _a, _b;
        return (_b = (_a = this.tags) === null || _a === void 0 ? void 0 : _a.some((tag) => tag.tagName === tagName)) !== null && _b !== void 0 ? _b : false;
    }
    /**
     * Return the first tag with the given name.
     *
     * You can optionally pass a parameter name that should be searched to.
     *
     * @param tagName  The name of the tag to look for.
     * @param paramName  An optional parameter name to look for.
     * @returns The found tag or undefined.
     */
    getTag(tagName, paramName) {
        var _a, _b;
        if (paramName !== undefined) {
            return (_a = this.tags) === null || _a === void 0 ? void 0 : _a.find((tag) => tag.tagName === tagName && tag.paramName === paramName);
        }
        return (_b = this.tags) === null || _b === void 0 ? void 0 : _b.find((tag) => tag.tagName === tagName);
    }
    /**
     * Removes all tags with the given tag name from this comment.
     */
    removeTags(...tags) {
        var _a;
        this.tags = (_a = this.tags) === null || _a === void 0 ? void 0 : _a.filter((tag) => !tags.includes(tag.tagName));
    }
    /**
     * Copy the data of the given comment into this comment.
     *
     * @param comment
     */
    clone() {
        var _a;
        const clone = new Comment(this.shortText, this.text);
        clone.tags = (_a = this.tags) === null || _a === void 0 ? void 0 : _a.map((tag) => tag.clone());
        return clone;
    }
}
exports.Comment = Comment;
//# sourceMappingURL=comment.js.map