"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeAliasReflection = void 0;
const abstract_1 = require("./abstract");
/**
 * Describes a type alias.
 *
 * ```ts
 * export type A = true
 * export type B = () => string
 * export type C<T extends { kind: string }> = T['kind']
 * ```
 */
class TypeAliasReflection extends abstract_1.Reflection {
    constructor(name, type, typeParameters) {
        super(name);
        this.kind = abstract_1.ReflectionKind.Alias;
        this.type = type;
        this.typeParameters = typeParameters;
    }
    serialize(serializer, init) {
        return {
            ...init,
            typeParameters: serializer.toObjects(this.typeParameters),
            type: serializer.toObject(this.type),
        };
    }
}
exports.TypeAliasReflection = TypeAliasReflection;
//# sourceMappingURL=alias.js.map