"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ClassReflection = exports.Visibility = void 0;
const abstract_1 = require("./abstract");
/**
 * Class members have visibility, enumeration members are always public, unless modified with a
 * visibility tag.
 */
var Visibility;
(function (Visibility) {
    Visibility["Public"] = "public";
    Visibility["Protected"] = "protected";
    Visibility["Private"] = "private";
})(Visibility = exports.Visibility || (exports.Visibility = {}));
/**
 * Describes a class.
 *
 * ```ts
 * class Foo {
 *   // added to children
 *   member: string
 *   static member: string
 *   method(): string;
 *   static method(): string;
 *   // added to construct signatures
 *   constructor();
 *   constructor(a: string);
 * }
 *
 * interface Foo extends Bar {
 *   //
 *   // added to signatures
 *   (): string
 * }
 * ```
 */
class ClassReflection extends abstract_1.ContainerReflection {
    constructor(name, signatures, constructSignatures, typeParameters, implementedTypes, extendedType) {
        super(name);
        this.kind = abstract_1.ReflectionKind.Class;
        this.signatures = signatures;
        this.constructSignatures = constructSignatures;
        this.typeParameters = typeParameters;
        this.implementedTypes = implementedTypes;
        this.extendedType = extendedType;
    }
    serialize(serializer, init) {
        const result = {
            ...init,
            signatures: serializer.toObjects(this.signatures),
            constructSignatures: serializer.toObjects(this.constructSignatures),
            typeParameters: serializer.toObjects(this.typeParameters),
            implementedTypes: serializer.toObjects(this.implementedTypes),
        };
        if (this.extendedType) {
            result.extendedType = serializer.toObject(this.extendedType);
        }
        return result;
    }
}
exports.ClassReflection = ClassReflection;
//# sourceMappingURL=class.js.map