import { ReflectionKind, ContainerReflection, Reflection } from "./abstract";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
/**
 * Describes an enum which may contain enum members.
 *
 * ```ts
 * const enum Enum { <-- Here
 *   a
 * }
 * ```
 */
export declare class EnumReflection extends ContainerReflection<EnumMemberReflection> {
    readonly kind = ReflectionKind.Enum;
    isConst: boolean;
    constructor(name: string, isConst: boolean);
    serialize(_serializer: Serializer, init: BaseSerialized<EnumReflection>): SerializedEnumReflection;
}
export interface SerializedEnumReflection extends Serialized<EnumReflection, "isConst"> {
}
/**
 * Describes an enum member. Members may have either a string or
 * number value.
 *
 * ```ts
 * enum Enum {
 *   a, // <-- Here
 *   b = "val" // <-- Here
 * }
 * ```
 */
export declare class EnumMemberReflection extends Reflection {
    readonly kind = ReflectionKind.EnumMember;
    value: string | number;
    constructor(name: string, value: string | number);
    serialize(_serializer: Serializer, init: BaseSerialized<EnumMemberReflection>): SerializedEnumMemberReflection;
}
export interface SerializedEnumMemberReflection extends Serialized<EnumMemberReflection, "value"> {
}
