"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.EnumMemberReflection = exports.EnumReflection = void 0;
const abstract_1 = require("./abstract");
/**
 * Describes an enum which may contain enum members.
 *
 * ```ts
 * const enum Enum { <-- Here
 *   a
 * }
 * ```
 */
class EnumReflection extends abstract_1.ContainerReflection {
    constructor(name, isConst) {
        super(name);
        this.kind = abstract_1.ReflectionKind.Enum;
        this.isConst = isConst;
    }
    serialize(_serializer, init) {
        return {
            ...init,
            isConst: this.isConst,
        };
    }
}
exports.EnumReflection = EnumReflection;
/**
 * Describes an enum member. Members may have either a string or
 * number value.
 *
 * ```ts
 * enum Enum {
 *   a, // <-- Here
 *   b = "val" // <-- Here
 * }
 * ```
 */
class EnumMemberReflection extends abstract_1.Reflection {
    constructor(name, value) {
        super(name);
        this.kind = abstract_1.ReflectionKind.EnumMember;
        this.value = value;
    }
    serialize(_serializer, init) {
        return {
            ...init,
            value: this.value,
        };
    }
}
exports.EnumMemberReflection = EnumMemberReflection;
//# sourceMappingURL=enum.js.map