"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InterfaceReflection = void 0;
const abstract_1 = require("./abstract");
/**
 * Describes an interface.
 *
 * ```ts
 * interface Foo {
 *   // added to children
 *   member: string
 *   // added to children
 *   method(): string;
 *   // added to signatures
 *   (): string
 *   // added to construct signatures
 *   new(): HTMLElement
 * }
 * ```
 */
class InterfaceReflection extends abstract_1.ContainerReflection {
    constructor(name, signatures, constructSignatures, typeParameters, extendedTypes) {
        super(name);
        this.kind = abstract_1.ReflectionKind.Interface;
        this.signatures = signatures;
        this.constructSignatures = constructSignatures;
        this.typeParameters = typeParameters;
        this.extendedTypes = extendedTypes;
    }
    serialize(serializer, init) {
        return {
            ...init,
            signatures: serializer.toObjects(this.signatures),
            constructSignatures: serializer.toObjects(this.constructSignatures),
            typeParameters: serializer.toObjects(this.typeParameters),
            extendedTypes: serializer.toObjects(this.extendedTypes),
        };
    }
}
exports.InterfaceReflection = InterfaceReflection;
//# sourceMappingURL=interface.js.map