import type { BaseSerialized, Serialized, Serializer } from "../../serialization";
import type { SomeType } from "../types";
import { Reflection, ReflectionKind } from "./abstract";
import type { ObjectReflection } from "./object";
/**
 * Describes a variable.
 *
 * To determine if a variable is declared with `const`, `let` or `var`, check {@link VariableReflection.flags}
 *
 * ```ts
 * export const a = true
 * export let b = Math.random()
 * export var c = [1, 2, 3]
 * // This is treated as a function.
 * export var notAVariableReflection = () => true
 * ```
 */
export declare class VariableReflection extends Reflection {
    readonly kind = ReflectionKind.Variable;
    type: SomeType | ObjectReflection;
    defaultValue?: string;
    constructor(name: string, type: SomeType, defaultValue?: string);
    serialize(serializer: Serializer, init: BaseSerialized<VariableReflection>): SerializedVariableReflection;
}
export interface SerializedVariableReflection extends Serialized<VariableReflection, "type" | "defaultValue"> {
}
