"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.VariableReflection = void 0;
const abstract_1 = require("./abstract");
/**
 * Describes a variable.
 *
 * To determine if a variable is declared with `const`, `let` or `var`, check {@link VariableReflection.flags}
 *
 * ```ts
 * export const a = true
 * export let b = Math.random()
 * export var c = [1, 2, 3]
 * // This is treated as a function.
 * export var notAVariableReflection = () => true
 * ```
 */
class VariableReflection extends abstract_1.Reflection {
    constructor(name, type, defaultValue) {
        super(name);
        this.kind = abstract_1.ReflectionKind.Variable;
        this.type = type;
        this.defaultValue = defaultValue;
    }
    serialize(serializer, init) {
        const result = {
            ...init,
            type: serializer.toObject(this.type),
        };
        if (typeof this.defaultValue === "string") {
            result.defaultValue = this.defaultValue;
        }
        return result;
    }
}
exports.VariableReflection = VariableReflection;
//# sourceMappingURL=variable.js.map