"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Type = exports.TypeKind = void 0;
const enum_1 = require("../../utils/enum");
/**
 * Defines the available type kinds. Analogous to the {@link ReflectionKind}
 * enum for reflections.
 */
var TypeKind;
(function (TypeKind) {
    TypeKind[TypeKind["Array"] = 1] = "Array";
    TypeKind[TypeKind["Conditional"] = 2] = "Conditional";
    TypeKind[TypeKind["IndexedAccess"] = 4] = "IndexedAccess";
    TypeKind[TypeKind["Inferred"] = 8] = "Inferred";
    TypeKind[TypeKind["Intersection"] = 16] = "Intersection";
    TypeKind[TypeKind["Intrinsic"] = 32] = "Intrinsic";
    TypeKind[TypeKind["Object"] = 64] = "Object";
    TypeKind[TypeKind["Property"] = 128] = "Property";
    TypeKind[TypeKind["Predicate"] = 256] = "Predicate";
    TypeKind[TypeKind["Query"] = 512] = "Query";
    TypeKind[TypeKind["Reference"] = 1024] = "Reference";
    TypeKind[TypeKind["Signature"] = 2048] = "Signature";
    TypeKind[TypeKind["Constructor"] = 4096] = "Constructor";
    TypeKind[TypeKind["SignatureParameter"] = 8192] = "SignatureParameter";
    TypeKind[TypeKind["Literal"] = 16384] = "Literal";
    TypeKind[TypeKind["Tuple"] = 32768] = "Tuple";
    TypeKind[TypeKind["TypeOperator"] = 65536] = "TypeOperator";
    TypeKind[TypeKind["TypeParameter"] = 131072] = "TypeParameter";
    TypeKind[TypeKind["Union"] = 262144] = "Union";
    TypeKind[TypeKind["Unknown"] = 524288] = "Unknown";
    TypeKind[TypeKind["Mapped"] = 1048576] = "Mapped";
    TypeKind[TypeKind["TupleMember"] = 2097152] = "TupleMember";
    TypeKind[TypeKind["Optional"] = 4194304] = "Optional";
})(TypeKind = exports.TypeKind || (exports.TypeKind = {}));
(function (TypeKind) {
    const LAST_KIND = TypeKind.Optional;
    TypeKind.All = LAST_KIND * 2 - 1;
    TypeKind.toKindArray = enum_1.makeToKindArray(LAST_KIND);
    TypeKind.toKindString = enum_1.makeToKindString(TypeKind);
})(TypeKind = exports.TypeKind || (exports.TypeKind = {}));
/**
 * Base class of all type definitions.
 */
class Type {
    /**
     * Return a string representation of this type.
     */
    toString() {
        return this.stringify(false);
    }
}
exports.Type = Type;
//# sourceMappingURL=abstract.js.map