import type { SomeType } from ".";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
import { Type, TypeKind } from "./abstract";
/**
 * Represents an array type.
 *
 * ```ts
 * type A = string[];
 * type B = Array<string>;
 * ```
 */
export declare class ArrayType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Array;
    /**
     * The type of the array elements.
     */
    elementType: SomeType;
    constructor(elementType: SomeType);
    /** @inheritdoc */
    clone(): ArrayType;
    /** @inheritdoc */
    stringify(_wrapped: boolean): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<ArrayType>): SerializedArrayType;
}
export interface SerializedArrayType extends Serialized<ArrayType, "elementType"> {
}
