"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ArrayType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents an array type.
 *
 * ```ts
 * type A = string[];
 * type B = Array<string>;
 * ```
 */
class ArrayType extends abstract_1.Type {
    constructor(elementType) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Array;
        this.elementType = elementType;
    }
    /** @inheritdoc */
    clone() {
        return new ArrayType(this.elementType.clone());
    }
    /** @inheritdoc */
    stringify(_wrapped) {
        return this.elementType.stringify(true) + "[]";
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            elementType: serializer.toObject(this.elementType),
        };
    }
}
exports.ArrayType = ArrayType;
//# sourceMappingURL=array.js.map