import type { SomeType } from ".";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
import { Type, TypeKind } from "./abstract";
/**
 * Represents a conditional type.
 *
 * ```ts
 * let value: C extends E ? T : F;
 * let value2: Check extends Extends ? True : False;
 * ```
 */
export declare class ConditionalType extends Type {
    checkType: SomeType;
    extendsType: SomeType;
    trueType: SomeType;
    falseType: SomeType;
    readonly kind = TypeKind.Conditional;
    constructor(checkType: SomeType, extendsType: SomeType, trueType: SomeType, falseType: SomeType);
    /** @inheritdoc */
    clone(): ConditionalType;
    /** @inheritdoc */
    stringify(wrapped: boolean): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<ConditionalType>): SerializedConditionalType;
}
export interface SerializedConditionalType extends Serialized<ConditionalType, "checkType" | "extendsType" | "trueType" | "falseType"> {
}
