"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConditionalType = void 0;
const abstract_1 = require("./abstract");
const utils_1 = require("./utils");
/**
 * Represents a conditional type.
 *
 * ```ts
 * let value: C extends E ? T : F;
 * let value2: Check extends Extends ? True : False;
 * ```
 */
class ConditionalType extends abstract_1.Type {
    constructor(checkType, extendsType, trueType, falseType) {
        super();
        this.checkType = checkType;
        this.extendsType = extendsType;
        this.trueType = trueType;
        this.falseType = falseType;
        this.kind = abstract_1.TypeKind.Conditional;
    }
    /** @inheritdoc */
    clone() {
        return new ConditionalType(this.checkType.clone(), this.extendsType.clone(), this.trueType.clone(), this.falseType.clone());
    }
    /** @inheritdoc */
    stringify(wrapped) {
        return utils_1.wrap(wrapped, `${this.checkType.stringify(true)} extends ${this.extendsType.stringify(true)} ? ${this.trueType.stringify(true)} : ${this.falseType.stringify(true)}`);
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            checkType: serializer.toObject(this.checkType),
            extendsType: serializer.toObject(this.extendsType),
            trueType: serializer.toObject(this.trueType),
            falseType: serializer.toObject(this.falseType),
        };
    }
}
exports.ConditionalType = ConditionalType;
//# sourceMappingURL=conditional.js.map