"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IndexedAccessType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents an indexed access type.
 */
class IndexedAccessType extends abstract_1.Type {
    constructor(objectType, indexType) {
        super();
        this.objectType = objectType;
        this.indexType = indexType;
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.IndexedAccess;
    }
    /** @inheritdoc */
    clone() {
        return new IndexedAccessType(this.objectType.clone(), this.indexType.clone());
    }
    /** @inheritdoc */
    stringify() {
        // The index type is contained within brackets and does not need parenthesis, even if complex.
        return `${this.objectType.stringify(true)}[${this.indexType.stringify(false)}]`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            indexType: serializer.toObject(this.indexType),
            objectType: serializer.toObject(this.objectType),
        };
    }
}
exports.IndexedAccessType = IndexedAccessType;
//# sourceMappingURL=indexed-access.js.map