import { Type, TypeKind } from ".";
import type { BaseSerialized, Serialized } from "../../serialization";
/**
 * Represents an inferred type, U in the example below.
 *
 * ```ts
 * type Z = Promise<string> extends Promise<infer U> ? U : never
 * ```
 */
export declare class InferredType extends Type {
    name: string;
    /** @inheritdoc */
    readonly kind = TypeKind.Inferred;
    constructor(name: string);
    /** @inheritdoc */
    clone(): InferredType;
    /** @inheritdoc */
    stringify(wrapped: boolean): string;
    /** @inheritdoc */
    serialize(_serializer: unknown, init: BaseSerialized<InferredType>): SerializedInferredType;
}
export interface SerializedInferredType extends Serialized<InferredType, "name"> {
}
