"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.InferredType = void 0;
const _1 = require(".");
const utils_1 = require("./utils");
/**
 * Represents an inferred type, U in the example below.
 *
 * ```ts
 * type Z = Promise<string> extends Promise<infer U> ? U : never
 * ```
 */
class InferredType extends _1.Type {
    constructor(name) {
        super();
        this.name = name;
        /** @inheritdoc */
        this.kind = _1.TypeKind.Inferred;
    }
    /** @inheritdoc */
    clone() {
        return new InferredType(this.name);
    }
    /** @inheritdoc */
    stringify(wrapped) {
        return utils_1.wrap(wrapped, `infer ${this.name}`);
    }
    /** @inheritdoc */
    serialize(_serializer, init) {
        return {
            ...init,
            name: this.name,
        };
    }
}
exports.InferredType = InferredType;
//# sourceMappingURL=inferred.js.map