"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntersectionType = void 0;
const _1 = require(".");
const utils_1 = require("./utils");
/**
 * Represents an intersection type.
 *
 * ```ts
 * let value: A & B;
 * ```
 */
class IntersectionType extends _1.Type {
    constructor(types) {
        super();
        /** @inheritdoc */
        this.kind = _1.TypeKind.Intersection;
        this.types = types;
    }
    /** @inheritdoc */
    clone() {
        return new IntersectionType(utils_1.cloned(this.types));
    }
    /** @inheritdoc */
    stringify(wrapped) {
        return utils_1.wrap(wrapped, this.types.map((type) => type.stringify(true)).join(" & "));
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            types: serializer.toObjects(this.types),
        };
    }
}
exports.IntersectionType = IntersectionType;
//# sourceMappingURL=intersection.js.map