import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
import { Type, TypeKind } from "./abstract";
/**
 * Represents an intrinsic type like `string` or `boolean`.
 *
 * ```ts
 * let value: number;
 * type A = unknown;
 * ```
 */
export declare class IntrinsicType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Intrinsic;
    /**
     * The name of the intrinsic type like `string` or `boolean`.
     */
    name: string;
    constructor(name: string);
    /** @inheritdoc */
    clone(): IntrinsicType;
    /** @inheritdoc */
    stringify(): string;
    /** @inheritdoc */
    serialize(_serializer: Serializer, init: BaseSerialized<IntrinsicType>): SerializedIntrinsicType;
}
export interface SerializedIntrinsicType extends Serialized<IntrinsicType, "name"> {
}
