"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.IntrinsicType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents an intrinsic type like `string` or `boolean`.
 *
 * ```ts
 * let value: number;
 * type A = unknown;
 * ```
 */
class IntrinsicType extends abstract_1.Type {
    constructor(name) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Intrinsic;
        this.name = name;
    }
    /** @inheritdoc */
    clone() {
        return new IntrinsicType(this.name);
    }
    /** @inheritdoc */
    stringify() {
        return this.name;
    }
    /** @inheritdoc */
    serialize(_serializer, init) {
        return {
            ...init,
            name: this.name,
        };
    }
}
exports.IntrinsicType = IntrinsicType;
//# sourceMappingURL=intrinsic.js.map