import { Type, TypeKind } from "./abstract";
import type { BaseSerialized, Serialized } from "../../serialization";
/**
 * BigInt values cannot be passed to JSON.stringify, and are not supported in all
 * supported Node versions yet.
 */
export interface PseudoBigInt {
    negative: boolean;
    /** Base 10 */
    value: string;
}
/**
 * Represents a literal type.
 *
 * ```ts
 * type Str = "DIV";
 * type Num = 1;
 * type Num2 = -1;
 * type Bool = true;
 * type Z = 123n;
 * ```
 */
export declare class LiteralType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Literal;
    /**
     * The literal value.
     */
    value: null | string | number | boolean | PseudoBigInt;
    constructor(value: LiteralType["value"]);
    /** @inheritdoc */
    clone(): LiteralType;
    /** @inheritdoc */
    stringify(): string;
    /** @inheritdoc */
    serialize(_serializer: unknown, init: BaseSerialized<LiteralType>): SerializedLiteralType;
}
export interface SerializedLiteralType extends Serialized<LiteralType, "value"> {
}
