"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LiteralType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents a literal type.
 *
 * ```ts
 * type Str = "DIV";
 * type Num = 1;
 * type Num2 = -1;
 * type Bool = true;
 * type Z = 123n;
 * ```
 */
class LiteralType extends abstract_1.Type {
    constructor(value) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Literal;
        this.value = value;
    }
    /** @inheritdoc */
    clone() {
        return new LiteralType(this.value);
    }
    /** @inheritdoc */
    stringify() {
        if (typeof this.value === "object" && this.value) {
            return `${this.value.negative ? "-" : ""}${this.value.value}n`;
        }
        return JSON.stringify(this.value);
    }
    /** @inheritdoc */
    serialize(_serializer, init) {
        return {
            ...init,
            value: this.value,
        };
    }
}
exports.LiteralType = LiteralType;
//# sourceMappingURL=literal.js.map