"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MappedType = exports.OptionalModifier = void 0;
const abstract_1 = require("./abstract");
var OptionalModifier;
(function (OptionalModifier) {
    OptionalModifier["None"] = "none";
    OptionalModifier["Add"] = "add";
    OptionalModifier["Remove"] = "remove";
})(OptionalModifier = exports.OptionalModifier || (exports.OptionalModifier = {}));
/**
 * Represents an intrinsic type like `string` or `boolean`.
 *
 * ```ts
 * let value: number;
 * type A = unknown;
 * ```
 */
class MappedType extends abstract_1.Type {
    constructor(readonlyModifier, parameter, optionalityModifier, type) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Mapped;
        this.readonlyModifier = readonlyModifier;
        this.parameter = parameter;
        this.optionalModifier = optionalityModifier;
        this.type = type;
    }
    /** @inheritdoc */
    clone() {
        return new MappedType(this.readonlyModifier, this.parameter.clone(), // already validated
        this.optionalModifier, this.type.clone());
    }
    /** @inheritdoc */
    stringify() {
        const prefix = {
            [OptionalModifier.None]: " ",
            [OptionalModifier.Add]: " readonly ",
            [OptionalModifier.Remove]: " -readonly ",
        }[this.readonlyModifier];
        const parameter = this.parameter.name + " in " + this.parameter.constraint.toString();
        const sep = {
            [OptionalModifier.None]: ": ",
            [OptionalModifier.Add]: "?: ",
            [OptionalModifier.Remove]: "-?: ",
        }[this.optionalModifier];
        return `{${prefix}[${parameter}]${sep}${this.type.toString()} }`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            readonlyModifier: this.readonlyModifier,
            parameter: serializer.toObject(this.parameter),
            optionalModifier: this.optionalModifier,
            type: serializer.toObject(this.type),
        };
    }
}
exports.MappedType = MappedType;
//# sourceMappingURL=mapped.js.map