import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
import { Type, TypeKind } from "./abstract";
import type { SignatureType, ConstructorType } from "./signature";
import type { SomeType } from ".";
/**
 * The most versatile type, describes any type of object with properties, methods,
 * signatures, and construct signatures.
 */
export declare class ObjectType extends Type {
    /** Includes methods, like the TS Type. */
    properties: PropertyType[];
    signatures: SignatureType[];
    constructSignatures: ConstructorType[];
    /** @inheritdoc */
    readonly kind = TypeKind.Object;
    constructor(
    /** Includes methods, like the TS Type. */
    properties: PropertyType[], signatures: SignatureType[], constructSignatures: ConstructorType[]);
    /** @inheritdoc */
    clone(): ObjectType;
    /** @inheritdoc */
    stringify(wrapped: boolean): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<ObjectType>): SerializedObjectType;
}
export interface SerializedObjectType extends Serialized<ObjectType, "properties" | "signatures" | "constructSignatures"> {
}
export declare class PropertyType extends Type {
    name: string;
    isReadonly: boolean;
    isOptional: boolean;
    propertyType: SomeType;
    /** @inheritdoc */
    readonly kind = TypeKind.Property;
    constructor(name: string, isReadonly: boolean, isOptional: boolean, propertyType: SomeType);
    /** @inheritdoc */
    clone(): PropertyType;
    /** @inheritdoc */
    stringify(wrapped: boolean): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<PropertyType>): SerializedPropertyType;
}
export interface SerializedPropertyType extends Serialized<PropertyType, "name" | "isReadonly" | "isOptional" | "propertyType"> {
}
