"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.OptionalType = void 0;
const assert_1 = require("assert");
const _1 = require(".");
/**
 * Represents an optional type, `string?` in the example below.
 *
 * ```ts
 * type Z = [string?]
 * ```
 */
class OptionalType extends _1.Type {
    constructor(type) {
        super();
        this.type = type;
        /** @inheritdoc */
        this.kind = _1.TypeKind.Optional;
    }
    /** @inheritdoc */
    clone() {
        return new OptionalType(this.type.clone());
    }
    /** @inheritdoc */
    stringify(wrapped) {
        assert_1.ok(wrapped == false);
        return this.type.stringify(true) + "?";
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            type: serializer.toObject(this.type),
        };
    }
}
exports.OptionalType = OptionalType;
//# sourceMappingURL=optional.js.map