import { Type, TypeKind } from "./abstract";
import type { SomeType } from ".";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
/**
 * Represents a type predicate.
 *
 * Note that this type is only valid in the return types of functions.
 *
 * ```ts
 * function isString(anything: any): anything is string {}
 * function assert(condition: boolean): asserts condition {}
 * ```
 */
export declare class PredicateType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Predicate;
    /**
     * The type that the identifier is tested to be.
     * May be undefined if the type is of the form `asserts val`.
     * Will be defined if the type is of the form `asserts val is string` or `val is string`.
     */
    targetType?: SomeType;
    /**
     * The identifier name which is tested by the predicate.
     */
    name: string;
    /**
     * True if the type is of the form `asserts val is string`, false if
     * the type is of the form `val is string`
     */
    asserts: boolean;
    constructor(name: string, asserts: boolean, targetType?: SomeType);
    /** @inheritdoc */
    clone(): PredicateType;
    /** @inheritdoc */
    stringify(wrapped: boolean): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<PredicateType>): SerializedPredicateType;
}
export interface SerializedPredicateType extends Serialized<PredicateType, "name" | "asserts" | "targetType"> {
}
