"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PredicateType = void 0;
const assert = require("assert");
const abstract_1 = require("./abstract");
/**
 * Represents a type predicate.
 *
 * Note that this type is only valid in the return types of functions.
 *
 * ```ts
 * function isString(anything: any): anything is string {}
 * function assert(condition: boolean): asserts condition {}
 * ```
 */
class PredicateType extends abstract_1.Type {
    constructor(name, asserts, targetType) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Predicate;
        this.name = name;
        this.asserts = asserts;
        this.targetType = targetType;
    }
    /** @inheritdoc */
    clone() {
        var _a;
        return new PredicateType(this.name, this.asserts, (_a = this.targetType) === null || _a === void 0 ? void 0 : _a.clone());
    }
    /** @inheritdoc */
    stringify(wrapped) {
        assert(wrapped === false, "Predicate types cannot be wrapped within other types.");
        const out = this.asserts ? ["asserts", this.name] : [this.name];
        if (this.targetType) {
            out.push("is", this.targetType.toString());
        }
        return out.join(" ");
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        const result = {
            ...init,
            name: this.name,
            asserts: this.asserts,
        };
        if (this.targetType) {
            result.targetType = serializer.toObject(this.targetType);
        }
        return result;
    }
}
exports.PredicateType = PredicateType;
//# sourceMappingURL=predicate.js.map