import { Type, TypeKind } from "./abstract";
import type { ReferenceType } from "./reference";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
/**
 * Represents a type that is constructed by querying the type of a reflection.
 * ```ts
 * const x = 1
 * type Z = typeof x // query on reflection for x
 * ```
 */
export declare class QueryType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Query;
    /**
     * A reference to the reflection whose type is being queried.
     */
    queryType: ReferenceType;
    constructor(reference: ReferenceType);
    /** @inheritdoc */
    clone(): QueryType;
    /** @inheritdoc */
    stringify(): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<QueryType>): SerializedQueryType;
}
export interface SerializedQueryType extends Serialized<QueryType, "queryType"> {
}
