"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.QueryType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents a type that is constructed by querying the type of a reflection.
 * ```ts
 * const x = 1
 * type Z = typeof x // query on reflection for x
 * ```
 */
class QueryType extends abstract_1.Type {
    constructor(reference) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Query;
        this.queryType = reference;
    }
    /** @inheritdoc */
    clone() {
        return new QueryType(this.queryType.clone());
    }
    /** @inheritdoc */
    stringify() {
        return `typeof ${this.queryType}`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            queryType: serializer.toObject(this.queryType),
        };
    }
}
exports.QueryType = QueryType;
//# sourceMappingURL=query.js.map