import type * as ts from "typescript";
import type { SomeType } from ".";
import type { ProjectReflection } from "../reflections";
import { Reflection } from "../reflections/abstract";
import { Type, TypeKind } from "./abstract";
import type { Serializer, BaseSerialized, Serialized } from "../../serialization";
/**
 * Represents a type that refers to another reflection like a class, interface or enum.
 *
 * ```ts
 * let value: MyClass;
 * ```
 */
export declare class ReferenceType extends Type {
    /** @inheritdoc */
    readonly kind = TypeKind.Reference;
    /**
     * The name of the referenced type.
     *
     * If the symbol cannot be found because it's not part of the documentation this
     * can be used to represent the type.
     */
    name: string;
    /**
     * The type arguments of this reference.
     */
    typeArguments: SomeType[];
    /**
     * The resolved reflection, if it exists.
     */
    get reflection(): Reflection | undefined;
    private _reference;
    private _project;
    private _preferValueSpace;
    constructor(name: string, typeArguments: SomeType[], reference: ts.Symbol | Reflection | number, preferValueSpace: boolean, project: ProjectReflection);
    /** @inheritdoc */
    clone(): ReferenceType;
    /** @inheritdoc */
    stringify(): string;
    /** @inheritdoc */
    serialize(serializer: Serializer, init: BaseSerialized<ReferenceType>): SerializedReferenceType;
}
export interface SerializedReferenceType extends Serialized<ReferenceType, "name" | "typeArguments"> {
    target?: number;
}
