"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ReferenceType = void 0;
const abstract_1 = require("../reflections/abstract");
const abstract_2 = require("./abstract");
const utils_1 = require("./utils");
const TYPE_CONTRIBUTING_KINDS = abstract_1.ReflectionKind.Interface |
    abstract_1.ReflectionKind.Class |
    abstract_1.ReflectionKind.Enum |
    abstract_1.ReflectionKind.Alias |
    abstract_1.ReflectionKind.Module;
/**
 * Represents a type that refers to another reflection like a class, interface or enum.
 *
 * ```ts
 * let value: MyClass;
 * ```
 */
class ReferenceType extends abstract_2.Type {
    constructor(name, typeArguments, reference, preferValueSpace, project) {
        super();
        /** @inheritdoc */
        this.kind = abstract_2.TypeKind.Reference;
        this.name = name;
        this.typeArguments = typeArguments;
        this._reference =
            reference instanceof abstract_1.Reflection ? reference.id : reference;
        this._preferValueSpace = preferValueSpace;
        this._project = project;
    }
    /**
     * The resolved reflection, if it exists.
     */
    get reflection() {
        if (typeof this._reference === "number") {
            return this._project.getReflectionById(this._reference);
        }
        for (const reflection of this._project.getReflectionsFromSymbol(this._reference)) {
            if (this._preferValueSpace !== reflection.kindOf(TYPE_CONTRIBUTING_KINDS)) {
                this._reference = reflection.id;
                return reflection;
            }
        }
        for (const reflection of this._project.getReflectionsFromSymbol(this._reference)) {
            this._reference = reflection.id;
            return reflection;
        }
    }
    /** @inheritdoc */
    clone() {
        return new ReferenceType(this.name, utils_1.cloned(this.typeArguments), this._reference, this._preferValueSpace, this._project);
    }
    /** @inheritdoc */
    stringify() {
        var _a, _b;
        const name = (_b = (_a = this.reflection) === null || _a === void 0 ? void 0 : _a.name) !== null && _b !== void 0 ? _b : this.name;
        let typeArgs = "";
        if (this.typeArguments.length) {
            typeArgs = `<${this.typeArguments
                .map((arg) => arg.toString())
                .join(", ")}>`;
        }
        return name + typeArgs;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        const result = {
            ...init,
            name: this.name,
            typeArguments: serializer.toObjects(this.typeArguments),
        };
        if (this.reflection) {
            result.target = this.reflection.id;
        }
        return result;
    }
}
exports.ReferenceType = ReferenceType;
//# sourceMappingURL=reference.js.map