"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TupleNamedMemberType = void 0;
const abstract_1 = require("./abstract");
const assert = require("assert");
class TupleNamedMemberType extends abstract_1.Type {
    constructor(name, isOptional, type) {
        super();
        this.name = name;
        this.isOptional = isOptional;
        this.type = type;
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.TupleMember;
    }
    /** @inheritdoc */
    clone() {
        return new TupleNamedMemberType(this.name, this.isOptional, this.type.clone());
    }
    /** @inheritdoc */
    stringify(wrapped) {
        assert(wrapped === false, "Tuple member types are never wrapped.");
        const tailModifier = this.isOptional ? "?" : "";
        return `${this.name}${tailModifier}: ${this.type}`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            name: this.name,
            isOptional: this.isOptional,
            type: serializer.toObject(this.type),
        };
    }
}
exports.TupleNamedMemberType = TupleNamedMemberType;
//# sourceMappingURL=tuple-member.js.map