"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TupleType = void 0;
const abstract_1 = require("./abstract");
const utils_1 = require("./utils");
/**
 * Represents a tuple type.
 *
 * ```ts
 * let value: [string, boolean];
 * ```
 */
class TupleType extends abstract_1.Type {
    constructor(elements) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Tuple;
        this.elements = elements;
    }
    /** @inheritdoc */
    clone() {
        return new TupleType(utils_1.cloned(this.elements));
    }
    /** @inheritdoc */
    stringify() {
        // No need for parenthesis here, each element is distinguishable and the whole type
        // is wrapped with brackets.
        return `[${this.elements.map((type) => type.stringify(false)).join(", ")}]`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            elements: serializer.toObjects(this.elements),
        };
    }
}
exports.TupleType = TupleType;
//# sourceMappingURL=tuple.js.map