"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeOperatorType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents a type operator type.
 *
 * ```ts
 * class A {}
 * class B<T extends keyof A> {}
 * ```
 */
class TypeOperatorType extends abstract_1.Type {
    constructor(target, operator) {
        super();
        this.target = target;
        this.operator = operator;
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.TypeOperator;
    }
    /** @inheritdoc */
    clone() {
        return new TypeOperatorType(this.target.clone(), this.operator);
    }
    /** @inheritdoc */
    stringify() {
        return `${this.operator} ${this.target.stringify(false)}`;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            operator: this.operator,
            target: serializer.toObject(this.target),
        };
    }
}
exports.TypeOperatorType = TypeOperatorType;
//# sourceMappingURL=type-operator.js.map