"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeParameterType = void 0;
const assert = require("assert");
const abstract_1 = require("./abstract");
/**
 * Represents a type parameter type.
 *
 * ```ts
 * function test<T extends string = 'bar'>() {
 *   // here     ^^^^^^^^^^^^^^^^^^^^^^^^
 *   let value: T;
 *   // but not ^ this is a reference
 * }
 * ```
 */
class TypeParameterType extends abstract_1.Type {
    constructor(name, constraint, defaultValue) {
        super();
        this.name = name;
        this.constraint = constraint;
        this.defaultValue = defaultValue;
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.TypeParameter;
        this.name = name;
        this.constraint = constraint;
        this.defaultValue = defaultValue;
    }
    /** @inheritdoc */
    clone() {
        var _a, _b;
        return new TypeParameterType(this.name, (_a = this.constraint) === null || _a === void 0 ? void 0 : _a.clone(), (_b = this.defaultValue) === null || _b === void 0 ? void 0 : _b.clone());
    }
    /** @inheritdoc */
    stringify(wrapped) {
        assert(wrapped === false, "Type parameters should never be wrapped in another type.");
        const extendsClause = this.constraint ? ` extends ${this.constraint}` : "";
        const defaultClause = this.defaultValue ? ` = ${this.defaultValue}` : "";
        return this.name + extendsClause + defaultClause;
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        const result = {
            ...init,
            name: this.name,
        };
        if (this.constraint) {
            result.constraint = serializer.toObject(this.constraint);
        }
        if (this.defaultValue) {
            result.defaultValue = serializer.toObject(this.defaultValue);
        }
        return result;
    }
}
exports.TypeParameterType = TypeParameterType;
//# sourceMappingURL=type-parameter.js.map