"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnionType = void 0;
const abstract_1 = require("./abstract");
const utils_1 = require("./utils");
/**
 * Represents an union type.
 *
 * ```ts
 * let value: string | string[];
 * ```
 */
class UnionType extends abstract_1.Type {
    constructor(types) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Union;
        this.types = types;
    }
    /** @inheritdoc */
    clone() {
        return new UnionType(utils_1.cloned(this.types));
    }
    /** @inheritdoc */
    stringify(wrapped) {
        return utils_1.wrap(wrapped, this.types.map((type) => type.stringify(true)).join(" | "));
    }
    /** @inheritdoc */
    serialize(serializer, init) {
        return {
            ...init,
            types: serializer.toObjects(this.types),
        };
    }
}
exports.UnionType = UnionType;
//# sourceMappingURL=union.js.map