"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UnknownType = void 0;
const abstract_1 = require("./abstract");
/**
 * Represents all unknown types.
 * Note that this is *not* equivalent to TypeScript's `unknown` type. TypeScript's
 * `unknown` type is an {@link IntrinsicType}. This type is reserved for reference types which
 * target reflections that do not exist in the documentation and for types which TypeDoc doesn't
 * know how to convert yet.
 */
class UnknownType extends abstract_1.Type {
    /**
     * Create a new instance of UnknownType.
     *
     * @param name A string representation of the type as returned from TypeScript compiler.
     */
    constructor(name) {
        super();
        /** @inheritdoc */
        this.kind = abstract_1.TypeKind.Unknown;
        this.name = name;
    }
    /** @inheritdoc */
    clone() {
        return new UnknownType(this.name);
    }
    /** @inheritdoc */
    stringify() {
        return this.name;
    }
    /** @inheritdoc */
    serialize(_serializer, init) {
        return {
            ...init,
            name: this.name,
        };
    }
}
exports.UnknownType = UnknownType;
//# sourceMappingURL=unknown.js.map