"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = void 0;
const models_1 = require("../../models");
// TODO: @event
/**
 * These tags are not useful to display in the generated documentation.
 * They should be ignored when parsing comments. Any relevant type information
 * (for JS users) will be consumed by TypeScript and need not be preserved
 * in the comment.
 *
 * Note that param/arg/argument/return/returns are not present.
 * These tags will have their type information stripped when parsing, but still
 * provide useful information for documentation.
 */
const TAG_BLACKLIST = [
    "augments",
    "callback",
    "class",
    "constructor",
    "enum",
    "extends",
    "this",
    "type",
    "typedef",
];
function load(app) {
    app.converter.on("reflectionCreated", (reflection) => {
        var _a, _b, _c;
        if (isHidden(reflection, Boolean(app.options.getCompilerOptions().stripInternal))) {
            (_a = reflection.project) === null || _a === void 0 ? void 0 : _a.removeReflection(reflection);
            return;
        }
        (_b = reflection.comment) === null || _b === void 0 ? void 0 : _b.removeTags(...TAG_BLACKLIST, ...app.options.getValue("excludeTags"));
        if (reflection.kindOf(models_1.ReflectionKind.Property, models_1.ReflectionKind.Accessor, models_1.ReflectionKind.Method)) {
            applyVisibilityModifiers(reflection);
        }
        if (reflection.kindOf(models_1.ReflectionKind.Module)) {
            (_c = reflection.comment) === null || _c === void 0 ? void 0 : _c.removeTags("packageDocumentation");
        }
    });
}
exports.load = load;
function applyVisibilityModifiers(reflection) {
    const comment = reflection.comment;
    if (!comment)
        return;
    if (comment.hasTag("private")) {
        reflection.visibility = "private" /* Private */;
    }
    if (comment.hasTag("protected")) {
        reflection.visibility = "protected" /* Protected */;
    }
    if (comment.hasTag("public")) {
        reflection.visibility = "public" /* Public */;
    }
    comment.removeTags("private", "protected", "public");
}
function isHidden(reflection, stripInternal) {
    if (!reflection.comment) {
        return false;
    }
    return (reflection.comment.hasTag("hidden") ||
        reflection.comment.hasTag("ignore") ||
        (stripInternal && reflection.comment.hasTag("internal")));
}
//# sourceMappingURL=index.js.map