"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = void 0;
const models_1 = require("../models");
/**
 * Define the sort order of reflections.
 */
const WEIGHTS = [
    models_1.ReflectionKind.Project,
    models_1.ReflectionKind.Module,
    models_1.ReflectionKind.Namespace,
    models_1.ReflectionKind.Enum,
    models_1.ReflectionKind.EnumMember,
    models_1.ReflectionKind.Class,
    models_1.ReflectionKind.Interface,
    models_1.ReflectionKind.Alias,
    models_1.ReflectionKind.Property,
    models_1.ReflectionKind.Variable,
    models_1.ReflectionKind.Function,
    models_1.ReflectionKind.Accessor,
    models_1.ReflectionKind.Method,
    models_1.ReflectionKind.Object,
    models_1.ReflectionKind.Parameter,
];
// TODO: Sort order option
const sorters = {
    default(a, b) {
        const aWeight = WEIGHTS.indexOf(a.kind);
        const bWeight = WEIGHTS.indexOf(b.kind);
        if (aWeight !== bWeight) {
            return aWeight - bWeight;
        }
        // TODO: Static properties first.
        // if (a.flags.isStatic && !b.flags.isStatic) {
        //     return 1;
        // }
        // if (!a.flags.isStatic && b.flags.isStatic) {
        //     return -1;
        // }
        return a.name.localeCompare(b.name);
    },
};
// Plugin which sorts reflections for display.
function load(app) {
    app.converter.on("end", (project) => {
        const toVisit = [project];
        let item = toVisit.pop();
        while (item) {
            if (item.isContainer()) {
                toVisit.push(...item.children);
                item.children.sort(sorters.default);
            }
            item = toVisit.pop();
        }
    });
}
exports.load = load;
//# sourceMappingURL=sort.js.map