export declare abstract class Host {
    static HOST_REGEX: RegExp;
    /**
     * Check if this host builder supports the given remote.
     * @param remote
     */
    static supports(remote: string): boolean;
    private _files;
    constructor(files: string[]);
    /**
     * Check if the given file is within this host.
     * @param file the absolute path to the file
     */
    containsFile(file: string): boolean;
    /**
     * Only called if {@link containsFile} returns true.
     * @param file the absolute path to the file
     */
    abstract createLink(file: string, line: number): string;
}
/**
 * Create links to files in GitHub repositories.
 *
 * Handles remotes in the format:
 * - https://github.com/project/repository.git
 * - git@github.company.com:project/repository.git
 */
export declare class GitHubHost extends Host {
    private repoRoot;
    private gitRevision;
    static HOST_REGEX: RegExp;
    private hostname;
    private project;
    private repository;
    constructor(repoRoot: string, remote: string, files: string[], gitRevision: string);
    createLink(file: string, line: number): string;
}
/**
 * Create links to files in Bitbucket repositories.
 *
 * Handles remotes in the format:
 * - git@bitbucket.org:project/repository.git
 * - https://username@bitbucket.org/project/repository.git
 */
export declare class BitbucketHost extends Host {
    private repoRoot;
    private gitRevision;
    static HOST_REGEX: RegExp;
    private repository;
    private project;
    constructor(repoRoot: string, remote: string, files: string[], gitRevision: string);
    createLink(file: string, line: number): string;
}
export declare class HostLinkResolver {
    private gitRemote;
    private gitRevision;
    constructor(gitRemote: string, gitRevision: string);
    private hosts;
    private ignored;
    tryGetUrl(file: string, line: number): string | undefined;
    private _tryCreateHost;
}
