import type { Application } from "../../application";
import { SomeReflection } from "../../models";
/**
 * Represents references of reflections to their defining source files.
 */
export interface SourceReference {
    /**
     * The filename of the source file.
     */
    fileName: string;
    /**
     * The number of the line that emitted the declaration. One based.
     */
    line: number;
    /**
     * The column in the line that contains the declaration. Zero based.
     */
    character: number;
    /**
     * URL for displaying the reflection this reference is attached to.
     * May not be set if the source file on does not belong to a git repository with a recognized git remote.
     */
    url?: string;
}
declare module "../../models/reflections/abstract" {
    interface Reflection {
        /**
         * A list of all source files that contributed to this reflection.
         * This is added by the {@link SourcePlugin}.
         */
        sources?: SourceReference[];
    }
}
declare module "../../serialization/schema" {
    interface SerializedReflection<T extends SomeReflection> {
        sources?: SourceReference[];
    }
}
export declare function load(app: Application): void;
