"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.load = void 0;
const path_1 = require("path");
const shell = require("shelljs");
const ts = require("typescript");
const models_1 = require("../../models");
const fs_1 = require("../../utils/fs");
const hosts_1 = require("./hosts");
const converter_1 = require("../../converter");
// Plugins specify a `load` function which will be called by TypeDoc to enable setting up event listeners.
function load(app) {
    // 3rd party plugins should add options to app here.
    // app.options.addDeclaration(...)
    shell.config.silent = true;
    let resolver;
    let rootDir;
    // At this point options haven't all been set, so wait to check them until we've started conversion.
    app.converter.on(converter_1.Converter.EVENT_BEGIN, (_, program) => {
        var _a, _b;
        if (!shell.which("git")) {
            return;
        }
        if (app.options.getValue("disableSources")) {
            return;
        }
        resolver = new hosts_1.HostLinkResolver(app.options.getValue("gitRemote"), app.options.getValue("gitRevision"));
        rootDir = path_1.resolve((_b = (_a = program.getCompilerOptions().baseUrl) !== null && _a !== void 0 ? _a : program.getCompilerOptions().rootDir) !== null && _b !== void 0 ? _b : fs_1.getCommonDirectory(program.getRootFileNames()));
        app.logger.verbose(`Root dir is ${rootDir}`);
        app.converter.on(converter_1.Converter.EVENT_REFLECTION_CREATED, (reflection, _, nodes) => {
            reflection.sources = nodes.map(getSourceReference);
        });
        app.serializer.addReflectionSerializer(models_1.ReflectionKind.All, {
            order: 100,
            serialize(reflection, data) {
                var _a;
                return {
                    ...data,
                    sources: (_a = reflection.sources) === null || _a === void 0 ? void 0 : _a.map((ref) => ({ ...ref })),
                };
            },
        });
    });
    function getSourceReference(node) {
        let position;
        if (node.name && node.name.end) {
            position = ts.getLineAndCharacterOfPosition(node.getSourceFile(), node.name.end);
        }
        else {
            position = ts.getLineAndCharacterOfPosition(node.getSourceFile(), node.pos);
        }
        const fileName = path_1.relative(rootDir, node.getSourceFile().fileName).replace(/\\/g, "/");
        return {
            fileName,
            line: position.line + 1,
            character: position.character,
            url: resolver.tryGetUrl(node.getSourceFile().fileName, position.line + 1),
        };
    }
}
exports.load = load;
//# sourceMappingURL=index.js.map