"use strict";
// Comments are special. Users can include markdown which will be rendered. They can also use [[include: file]]
// to include a file within their comment, or media://file to link to images or attachments.
Object.defineProperty(exports, "__esModule", { value: true });
exports.replaceMedia = exports.replaceIncludes = exports.parseMarkdown = void 0;
const Marked = require("marked");
const path = require("path");
const fs_1 = require("fs");
// TODO: {@link}, [[link]]
function parseMarkdown(markdown, reflection, router, highlighter) {
    const renderer = new Marked.Renderer();
    renderer.heading = (text, level, raw) => {
        const slug = router.createSlug(reflection, raw);
        return `<h${level}><a href="#${slug}" id="${slug}">${text}</a></h${level}>`;
    };
    Marked.use({
        renderer,
        highlight: (code, lang) => highlighter.highlight(code, lang),
    });
    return Marked(markdown);
}
exports.parseMarkdown = parseMarkdown;
const INCLUDE_PATTERN = /\[\[include:([^\]]+?)\]\]/g;
function replaceIncludes(includesDir, text, logger) {
    if (includesDir === "") {
        return text;
    }
    return text.replace(INCLUDE_PATTERN, (match, file) => {
        const resolved = path.join(includesDir, file.trim());
        try {
            return fs_1.readFileSync(resolved, "utf-8");
        }
        catch (_a) {
            logger.error(`Could not find file to include: ${file} => ${resolved}`);
            return match;
        }
    });
}
exports.replaceIncludes = replaceIncludes;
const MEDIA_PATTERN = /media:\/\/([^ ")\]}]+)/g;
function replaceMedia(mediaDir, text, logger, reflection, router) {
    if (mediaDir === "") {
        return text;
    }
    return text.replace(MEDIA_PATTERN, (match, file) => {
        const resolved = path.join(mediaDir, file.trim());
        if (fs_1.existsSync(resolved)) {
            return router.createMediaLink(reflection, file);
        }
        else {
            logger.error(`Could not find media file: ${file} => ${resolved}`);
            return match;
        }
    });
}
exports.replaceMedia = replaceMedia;
//# sourceMappingURL=comment.js.map