"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.minimalThemeDefinition = exports.defaultThemeDefinition = void 0;
const fs_1 = require("fs");
const path_1 = require("path");
const preact_1 = require("preact");
const fs_2 = require("../utils/fs");
const default_templates_1 = require("./default-templates");
const router_1 = require("./router");
const STATIC_DIR = path_1.join(__dirname, "../../../static");
// Keep this small, it will be inlined on EVERY page.
const THEME_JS = fs_1.readFileSync(path_1.join(STATIC_DIR, "theme.js"), "utf-8").trim();
const STYLE_CSS = fs_1.readFileSync(path_1.join(STATIC_DIR, "style.css"), "utf-8").trim();
exports.defaultThemeDefinition = {
    router: router_1.ThemeRouter,
    templates: default_templates_1.DefaultTemplates,
    preRender: {
        "default:theme-switcher": ({ hooks }) => {
            hooks.on("body.begin", () => (preact_1.createElement("script", { dangerouslySetInnerHTML: { __html: THEME_JS } })));
        },
        "default:style.css": ({ hooks, router }) => {
            hooks.on("head.end", (reflection) => (preact_1.createElement("link", { rel: "stylesheet", href: router.createAssetLink(reflection, "style.css") })));
        },
        "default:theme.css": ({ hooks, router }) => {
            hooks.on("head.end", (reflection) => (preact_1.createElement("link", { rel: "stylesheet", href: router.createAssetLink(reflection, "theme.css") })));
        },
    },
    postRender: {
        "default:style.css": ({ outDir, router }) => {
            return fs_2.copyFile(path_1.join(STATIC_DIR, "style.css"), path_1.join(outDir, router.getAssetDirectory(), "style.css"));
        },
        "default:theme.css": ({ outDir, router, highlighter }) => {
            return fs_2.writeFile(path_1.join(outDir, router.getAssetDirectory(), "theme.css"), highlighter.getStyles());
        },
        "default:media": ({ app, outDir, router }) => {
            if (app.options.getValue("media")) {
                return fs_2.copy(app.options.getValue("media"), path_1.join(outDir, router.getMediaDirectory()));
            }
        },
    },
};
exports.minimalThemeDefinition = {
    router: router_1.MinimalThemeRouter,
    preRender: {
        "minimal:style": ({ hooks }) => {
            hooks.on("head.end", () => (preact_1.createElement("style", { dangerouslySetInnerHTML: { __html: STYLE_CSS } })));
        },
    },
    // Unfortunately, we can't disable default:theme.css here...
    // This should be possible if/when https://github.com/shikijs/shiki/issues/33#issuecomment-678589764 is done.
    suppress: ["default:style.css"],
};
//# sourceMappingURL=theme.js.map