/**
 * Inserts an item into an array sorted by order. If two items have the same order,
 * the item inserted later will be placed later in the array.
 * @param arr modified by inserting item.
 * @param item
 */
export declare function insertOrderSorted<T extends {
    order?: number;
}>(arr: T[], item: T): T[];
/**
 * Performs a binary search of a given array, returning the index of the first item
 * for which `partition` returns true. Returns the -1 if there are no items in `arr`
 * such that `partition(item)` is true.
 * @param arr
 * @param partition should return true while less than the partition point.
 */
export declare function binaryFindPartition<T>(arr: readonly T[], partition: (item: T) => boolean): number;
/**
 * Removes an item from the array if the array exists and the item is included
 * within it.
 * @param arr
 * @param item
 */
export declare function removeIfPresent<T>(arr: T[] | undefined, item: T): void;
/**
 * Filters out duplicate values from the array. Order is preserved. Returns
 * a copy of the input array.
 */
export declare function uniq<T>(arr: readonly T[]): T[];
export declare type Zip<T extends any[][]> = {
    [K in keyof T]: T[K] extends Array<infer U> ? U : never;
};
/**
 * Standard zip function, expects that all arrays have the same length.
 */
export declare function zip<T extends any[][]>(...arrays: T): Zip<T>[];
export declare function waterfall<T, U>(arr: readonly T[], fn: (item: T) => U | Promise<U>): Promise<U[]>;
export declare function filterMap<T, U>(arr: Iterable<T>, mapper: (item: T) => undefined | null | U): U[];
