import type { Logger } from "./loggers";
/**
 * Get the longest directory path common to all files.
 *
 * Used to infer a root directory for a project based on the input files if `rootDir` is not set.
 * @param files
 */
export declare function getCommonDirectory(files: readonly string[]): string;
/**
 * Expand a list of input files and directories to get input files for a program.
 *
 * @param entryPoint The list of files that should be expanded.
 * @param excludePatterns Patterns to test files not in the entryPoint parameter against for exclusion.
 * @param allowJs Whether or not to include JS files in the result.
 * @returns The list of input files with expanded directories.
 */
export declare function expandDirectories(entryPoint: readonly string[], excludePatterns: readonly string[], allowJs: boolean, logger?: Logger): Promise<string[]>;
export declare function writeFile(path: string, content: string): Promise<void>;
export declare function copyFile(src: string, dest: string): Promise<void>;
/**
 * Copy a file or directory recursively.
 */
export declare function copy(src: string, dest: string): Promise<void>;
/**
 * Async recursive rmdir. Node v12.10.0 adds the { recursive: true } option to
 * the native fs rmdir function, but we don't require Node 12 yet.
 * @param target
 */
export declare function remove(target: string): Promise<void>;
